require "black_vulture_client/version"

module BlackVulture

  class Client
    attr_accessor :email, :token

    def initialize(email, token)
      @email = email
      @token = token
    end

    def list_facts(line)
      url_path = "/facts/#{line}.json"
      uri = uri(url_path)
      response = get(uri)
      JSON.parse(response.body)
    end

    def create_report(line, query)
      uri = uri_for_report(line, query)
      response = get(uri)
      JSON.parse(response.body)
    end

    def create_fact(payload)
      uri = uri('/facts.json')
      response = post(uri, payload)
      JSON.parse(response.body)
    end

    def update_fact(payload)
      uri = uri('/facts/update.json')
      response = post(uri, payload)
      JSON.parse(response.body)
    end

    private

    def headers
      {
        'X-User-Token' => @token,
        'X-User-Email' => @email,
        'Accept' => 'application/json',
        'Content-Type' => 'application/json'
      }
    end

    def host
      ENV["BLACK_VULTURE_URL"] || "http://52.32.38.238"
    end

    def uri(name)
      URI.parse("#{host}#{name}")
    end

    def build_http(uri)
      Net::HTTP.new(uri.host, uri.port)
    end

    def get(uri)
      build_http(uri).get(uri.request_uri, headers)
    end

    def post(uri, payload)
      build_http(uri).post(uri.path, payload.to_json, headers)
    end

    def uri_for_report(line, query)
      URI.parse("#{host}/reports/#{line}#{query}")
    end
  end
end
